==> haskell-rerebase-1.18-59-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-rerebase.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 rerebase
version:              1.18
visibility:           public
id:                   rerebase-1.18-AEIZe7duVVxLZFm39qMxW2
key:                  rerebase-1.18-AEIZe7duVVxLZFm39qMxW2
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/rerebase 
synopsis:
    Reexports from "base" with a bunch of other standard libraries

description:
    A rich drop-in replacement for \"base\".
    For details and docs please visit
    <https://github.com/nikita-volkov/rerebase the project'\''s GitHub page>.

abi:                  e49d31e62cce7c2c050e7d6f4430e3aa
exposed-modules:
    Control.Applicative Control.Applicative.Backwards
    Control.Applicative.Lift Control.Arrow Control.Category
    Control.Comonad Control.Concurrent Control.Concurrent.Chan
    Control.Concurrent.MVar Control.Concurrent.QSem
    Control.Concurrent.QSemN Control.Concurrent.STM
    Control.Concurrent.STM.TArray Control.Concurrent.STM.TBQueue
    Control.Concurrent.STM.TChan Control.Concurrent.STM.TMVar
    Control.Concurrent.STM.TQueue Control.Concurrent.STM.TSem
    Control.Concurrent.STM.TVar Control.DeepSeq Control.Exception
    Control.Exception.Base Control.Monad Control.Monad.Cont
    Control.Monad.Cont.Class Control.Monad.Error.Class
    Control.Monad.Fail Control.Monad.Fix Control.Monad.IO.Class
    Control.Monad.Identity Control.Monad.RWS Control.Monad.RWS.Class
    Control.Monad.RWS.Lazy Control.Monad.RWS.Strict
    Control.Monad.Reader Control.Monad.Reader.Class Control.Monad.ST
    Control.Monad.ST.Lazy Control.Monad.ST.Lazy.Safe
    Control.Monad.ST.Lazy.Unsafe Control.Monad.ST.Safe
    Control.Monad.ST.Strict Control.Monad.ST.Unsafe Control.Monad.STM
    Control.Monad.Signatures Control.Monad.State
    Control.Monad.State.Class Control.Monad.State.Lazy
    Control.Monad.State.Strict Control.Monad.Trans
    Control.Monad.Trans.Class Control.Monad.Trans.Cont
    Control.Monad.Trans.Except Control.Monad.Trans.Identity
    Control.Monad.Trans.Maybe Control.Monad.Trans.RWS
    Control.Monad.Trans.RWS.Lazy Control.Monad.Trans.RWS.Strict
    Control.Monad.Trans.Reader Control.Monad.Trans.State
    Control.Monad.Trans.State.Lazy Control.Monad.Trans.State.Strict
    Control.Monad.Trans.Writer Control.Monad.Trans.Writer.Lazy
    Control.Monad.Trans.Writer.Strict Control.Monad.Writer
    Control.Monad.Writer.Class Control.Monad.Writer.Lazy
    Control.Monad.Writer.Strict Control.Monad.Zip Control.Selective
    Control.Selective.Free Control.Selective.Multi
    Control.Selective.Rigid.Free Control.Selective.Rigid.Freer
    Data.Biapplicative Data.Bifoldable Data.Bifunctor
    Data.Bifunctor.Apply Data.Bifunctor.Biff Data.Bifunctor.Clown
    Data.Bifunctor.Flip Data.Bifunctor.Join Data.Bifunctor.Joker
    Data.Bifunctor.Product Data.Bifunctor.Tannen Data.Bifunctor.Wrapped
    Data.Bitraversable Data.Bits Data.Bool Data.ByteString
    Data.ByteString.Builder Data.ByteString.Builder.Extra
    Data.ByteString.Builder.Internal Data.ByteString.Builder.Prim
    Data.ByteString.Builder.Prim.Internal
    Data.ByteString.Builder.Scientific Data.ByteString.Char8
    Data.ByteString.Internal Data.ByteString.Lazy
    Data.ByteString.Lazy.Char8 Data.ByteString.Lazy.Internal
    Data.ByteString.Short Data.ByteString.Short.Internal
    Data.ByteString.Unsafe Data.Char Data.Coerce Data.Complex
    Data.DList Data.Data Data.Dynamic Data.Either
    Data.Either.Combinators Data.Either.Validation Data.Eq Data.Fixed
    Data.Foldable Data.Function Data.Functor Data.Functor.Alt
    Data.Functor.Apply Data.Functor.Bind Data.Functor.Bind.Class
    Data.Functor.Bind.Trans Data.Functor.Classes Data.Functor.Compose
    Data.Functor.Constant Data.Functor.Contravariant
    Data.Functor.Contravariant.Compose
    Data.Functor.Contravariant.Divisible Data.Functor.Extend
    Data.Functor.Identity Data.Functor.Invariant
    Data.Functor.Invariant.TH Data.Functor.Plus Data.Functor.Product
    Data.Functor.Reverse Data.Functor.Sum Data.Graph Data.Group
    Data.Groupoid Data.HashMap.Lazy Data.HashMap.Strict Data.HashSet
    Data.Hashable Data.IORef Data.Int Data.IntMap Data.IntMap.Lazy
    Data.IntMap.Strict Data.IntSet Data.Isomorphism Data.Ix Data.Kind
    Data.List Data.List.NonEmpty Data.List1 Data.Map Data.Map.Lazy
    Data.Map.Strict Data.Maybe Data.Monoid Data.Ord Data.Profunctor
    Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda Data.Proxy Data.Ratio
    Data.STRef Data.STRef.Lazy Data.STRef.Strict Data.Scientific
    Data.Semigroup Data.Semigroup.Bifoldable
    Data.Semigroup.Bitraversable Data.Semigroup.Foldable
    Data.Semigroup.Foldable.Class Data.Semigroup.Traversable
    Data.Semigroup.Traversable.Class Data.Semigroupoid
    Data.Semigroupoid.Dual Data.Semigroupoid.Ob
    Data.Semigroupoid.Static Data.Sequence Data.Set Data.String
    Data.Text Data.Text.Array Data.Text.Encoding
    Data.Text.Encoding.Error Data.Text.Foreign Data.Text.IO
    Data.Text.Internal Data.Text.Lazy Data.Text.Lazy.Builder
    Data.Text.Lazy.Builder.Int Data.Text.Lazy.Builder.RealFloat
    Data.Text.Lazy.Builder.Scientific Data.Text.Lazy.Encoding
    Data.Text.Lazy.IO Data.Text.Lazy.Read Data.Text.Read
    Data.Text.Unsafe Data.Time Data.Time.Calendar
    Data.Time.Calendar.Easter Data.Time.Calendar.Julian
    Data.Time.Calendar.MonthDay Data.Time.Calendar.OrdinalDate
    Data.Time.Calendar.WeekDate Data.Time.Clock Data.Time.Clock.POSIX
    Data.Time.Clock.TAI Data.Time.Compat Data.Time.Format
    Data.Time.Format.ISO8601 Data.Time.LocalTime Data.Traversable
    Data.Traversable.Instances Data.Tree Data.Tuple Data.Type.Bool
    Data.Type.Coercion Data.Type.Equality Data.Typeable Data.UUID
    Data.Unique Data.Vector Data.Vector.Fusion.Stream.Monadic
    Data.Vector.Fusion.Util Data.Vector.Generic
    Data.Vector.Generic.Base Data.Vector.Generic.Mutable
    Data.Vector.Generic.New Data.Vector.Instances
    Data.Vector.Internal.Check Data.Vector.Mutable
    Data.Vector.Primitive Data.Vector.Primitive.Mutable
    Data.Vector.Storable Data.Vector.Storable.Internal
    Data.Vector.Storable.Mutable Data.Vector.Unboxed
    Data.Vector.Unboxed.Base Data.Vector.Unboxed.Mutable Data.Version
    Data.Void Data.Void.Unsafe Data.Word Debug.Trace Foreign Foreign.C
    Foreign.C.Error Foreign.C.String Foreign.C.Types Foreign.Concurrent
    Foreign.ForeignPtr Foreign.ForeignPtr.Safe
    Foreign.ForeignPtr.Unsafe Foreign.Marshal Foreign.Marshal.Alloc
    Foreign.Marshal.Array Foreign.Marshal.Error Foreign.Marshal.Pool
    Foreign.Marshal.Safe Foreign.Marshal.Unsafe Foreign.Marshal.Utils
    Foreign.Ptr Foreign.Safe Foreign.StablePtr Foreign.Storable GHC.Arr
    GHC.Base GHC.Char GHC.Conc GHC.Conc.IO GHC.Conc.Signal
    GHC.Conc.Sync GHC.ConsoleHandler GHC.Constants GHC.Desugar GHC.Enum
    GHC.Environment GHC.Err GHC.Exception GHC.Exts GHC.Fingerprint
    GHC.Fingerprint.Type GHC.Float GHC.Float.ConversionUtils
    GHC.Float.RealFracMethods GHC.Foreign GHC.ForeignPtr GHC.GHCi
    GHC.Generics GHC.IO GHC.IO.Buffer GHC.IO.BufferedIO GHC.IO.Device
    GHC.IO.Encoding GHC.IO.Encoding.CodePage GHC.IO.Encoding.Failure
    GHC.IO.Encoding.Iconv GHC.IO.Encoding.Latin1 GHC.IO.Encoding.Types
    GHC.IO.Encoding.UTF16 GHC.IO.Encoding.UTF32 GHC.IO.Encoding.UTF8
    GHC.IO.Exception GHC.IO.FD GHC.IO.Handle GHC.IO.Handle.FD
    GHC.IO.Handle.Internals GHC.IO.Handle.Text GHC.IO.Handle.Types
    GHC.IO.IOMode GHC.IOArray GHC.IORef GHC.Int GHC.List GHC.MVar
    GHC.Num GHC.OverloadedLabels GHC.Pack GHC.Profiling GHC.Ptr
    GHC.Read GHC.Real GHC.Records GHC.ST GHC.STRef GHC.Show GHC.Stable
    GHC.Stack GHC.Stats GHC.Storable GHC.TopHandler GHC.TypeLits
    GHC.TypeNats GHC.Unicode GHC.Weak GHC.Word Numeric Numeric.Natural
    Prelude System.CPUTime System.Console.GetOpt System.Environment
    System.Exit System.IO System.IO.Error System.IO.Unsafe System.Info
    System.Mem System.Mem.StableName System.Mem.Weak
    System.Posix.Internals System.Posix.Types System.Timeout
    Text.ParserCombinators.ReadP Text.ParserCombinators.ReadPrec
    Text.Printf Text.Read Text.Read.Lex Text.Show Text.Show.Functions
    Unsafe.Coerce

import-dirs:          /usr/lib/ghc-9.2.8/site-local/rerebase-1.18
library-dirs:         /usr/lib/ghc-9.2.8/site-local/rerebase-1.18
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rerebase
hs-libraries:         HSrerebase-1.18-AEIZe7duVVxLZFm39qMxW2
depends:              rebase-1.18-FQAQGm9iaGfL8BitFbWhNK
haddock-interfaces:   /usr/share/doc/haskell-rerebase/html/rerebase.haddock
haddock-html:         /usr/share/doc/haskell-rerebase/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-rerebase-1.20-23.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-rerebase.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 rerebase
version:              1.20
visibility:           public
id:                   rerebase-1.20-KILABYYoZGG2GSka2hVFDU
key:                  rerebase-1.20-KILABYYoZGG2GSka2hVFDU
license:              MIT
copyright:            (c) 2016, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/rerebase 
synopsis:
    Reexports from "base" with a bunch of other standard libraries

description:
    A rich drop-in replacement for \"base\".
    For details and docs please visit
    <https://github.com/nikita-volkov/rerebase the project'\''s GitHub page>.

abi:                  74409adec0ba3bada639b6d6455eb54d
exposed-modules:
    Control.Applicative Control.Applicative.Backwards
    Control.Applicative.Lift Control.Arrow Control.Category
    Control.Comonad Control.Concurrent Control.Concurrent.Chan
    Control.Concurrent.MVar Control.Concurrent.QSem
    Control.Concurrent.QSemN Control.Concurrent.STM
    Control.Concurrent.STM.TArray Control.Concurrent.STM.TBQueue
    Control.Concurrent.STM.TChan Control.Concurrent.STM.TMVar
    Control.Concurrent.STM.TQueue Control.Concurrent.STM.TSem
    Control.Concurrent.STM.TVar Control.DeepSeq Control.Exception
    Control.Exception.Base Control.Monad Control.Monad.Cont
    Control.Monad.Cont.Class Control.Monad.Error.Class
    Control.Monad.Fail Control.Monad.Fix Control.Monad.IO.Class
    Control.Monad.Identity Control.Monad.RWS Control.Monad.RWS.Class
    Control.Monad.RWS.Lazy Control.Monad.RWS.Strict
    Control.Monad.Reader Control.Monad.Reader.Class Control.Monad.ST
    Control.Monad.ST.Lazy Control.Monad.ST.Lazy.Safe
    Control.Monad.ST.Lazy.Unsafe Control.Monad.ST.Safe
    Control.Monad.ST.Strict Control.Monad.ST.Unsafe Control.Monad.STM
    Control.Monad.Signatures Control.Monad.State
    Control.Monad.State.Class Control.Monad.State.Lazy
    Control.Monad.State.Strict Control.Monad.Trans
    Control.Monad.Trans.Class Control.Monad.Trans.Cont
    Control.Monad.Trans.Except Control.Monad.Trans.Identity
    Control.Monad.Trans.Maybe Control.Monad.Trans.RWS
    Control.Monad.Trans.RWS.Lazy Control.Monad.Trans.RWS.Strict
    Control.Monad.Trans.Reader Control.Monad.Trans.State
    Control.Monad.Trans.State.Lazy Control.Monad.Trans.State.Strict
    Control.Monad.Trans.Writer Control.Monad.Trans.Writer.Lazy
    Control.Monad.Trans.Writer.Strict Control.Monad.Writer
    Control.Monad.Writer.Class Control.Monad.Writer.Lazy
    Control.Monad.Writer.Strict Control.Monad.Zip Control.Selective
    Control.Selective.Free Control.Selective.Multi
    Control.Selective.Rigid.Free Control.Selective.Rigid.Freer
    Data.Biapplicative Data.Bifoldable Data.Bifunctor
    Data.Bifunctor.Apply Data.Bifunctor.Biff Data.Bifunctor.Clown
    Data.Bifunctor.Flip Data.Bifunctor.Join Data.Bifunctor.Joker
    Data.Bifunctor.Product Data.Bifunctor.Tannen Data.Bifunctor.Wrapped
    Data.Bitraversable Data.Bits Data.Bool Data.ByteString
    Data.ByteString.Builder Data.ByteString.Builder.Extra
    Data.ByteString.Builder.Internal Data.ByteString.Builder.Prim
    Data.ByteString.Builder.Prim.Internal
    Data.ByteString.Builder.Scientific Data.ByteString.Char8
    Data.ByteString.Internal Data.ByteString.Lazy
    Data.ByteString.Lazy.Char8 Data.ByteString.Lazy.Internal
    Data.ByteString.Short Data.ByteString.Short.Internal
    Data.ByteString.Unsafe Data.Char Data.Coerce Data.Complex
    Data.DList Data.Data Data.Dynamic Data.Either
    Data.Either.Combinators Data.Either.Validation Data.Eq Data.Fixed
    Data.Foldable Data.Function Data.Functor Data.Functor.Alt
    Data.Functor.Apply Data.Functor.Bind Data.Functor.Bind.Class
    Data.Functor.Bind.Trans Data.Functor.Classes Data.Functor.Compose
    Data.Functor.Constant Data.Functor.Contravariant
    Data.Functor.Contravariant.Compose
    Data.Functor.Contravariant.Divisible Data.Functor.Extend
    Data.Functor.Identity Data.Functor.Invariant
    Data.Functor.Invariant.TH Data.Functor.Plus Data.Functor.Product
    Data.Functor.Reverse Data.Functor.Sum Data.Graph Data.Group
    Data.Groupoid Data.HashMap.Lazy Data.HashMap.Strict Data.HashSet
    Data.Hashable Data.IORef Data.Int Data.IntMap Data.IntMap.Lazy
    Data.IntMap.Strict Data.IntSet Data.Isomorphism Data.Ix Data.Kind
    Data.List Data.List.NonEmpty Data.List1 Data.Map Data.Map.Lazy
    Data.Map.Strict Data.Maybe Data.Monoid Data.Ord Data.Profunctor
    Data.Profunctor.Adjunction Data.Profunctor.Cayley
    Data.Profunctor.Choice Data.Profunctor.Closed
    Data.Profunctor.Composition Data.Profunctor.Mapping
    Data.Profunctor.Monad Data.Profunctor.Ran Data.Profunctor.Rep
    Data.Profunctor.Sieve Data.Profunctor.Strong
    Data.Profunctor.Traversing Data.Profunctor.Types
    Data.Profunctor.Unsafe Data.Profunctor.Yoneda Data.Proxy Data.Ratio
    Data.STRef Data.STRef.Lazy Data.STRef.Strict Data.Scientific
    Data.Semigroup Data.Semigroup.Bifoldable
    Data.Semigroup.Bitraversable Data.Semigroup.Foldable
    Data.Semigroup.Foldable.Class Data.Semigroup.Traversable
    Data.Semigroup.Traversable.Class Data.Semigroupoid
    Data.Semigroupoid.Dual Data.Semigroupoid.Ob
    Data.Semigroupoid.Static Data.Sequence Data.Set Data.String
    Data.Text Data.Text.Array Data.Text.Encoding
    Data.Text.Encoding.Error Data.Text.Foreign Data.Text.IO
    Data.Text.Internal Data.Text.Lazy Data.Text.Lazy.Builder
    Data.Text.Lazy.Builder.Int Data.Text.Lazy.Builder.RealFloat
    Data.Text.Lazy.Builder.Scientific Data.Text.Lazy.Encoding
    Data.Text.Lazy.IO Data.Text.Lazy.Read Data.Text.Read
    Data.Text.Unsafe Data.Time Data.Time.Calendar
    Data.Time.Calendar.Easter Data.Time.Calendar.Julian
    Data.Time.Calendar.MonthDay Data.Time.Calendar.OrdinalDate
    Data.Time.Calendar.WeekDate Data.Time.Clock Data.Time.Clock.POSIX
    Data.Time.Clock.TAI Data.Time.Compat Data.Time.Format
    Data.Time.Format.ISO8601 Data.Time.LocalTime Data.Traversable
    Data.Traversable.Instances Data.Tree Data.Tuple Data.Type.Bool
    Data.Type.Coercion Data.Type.Equality Data.Typeable Data.UUID
    Data.Unique Data.Vector Data.Vector.Fusion.Stream.Monadic
    Data.Vector.Fusion.Util Data.Vector.Generic
    Data.Vector.Generic.Base Data.Vector.Generic.Mutable
    Data.Vector.Generic.New Data.Vector.Instances
    Data.Vector.Internal.Check Data.Vector.Mutable
    Data.Vector.Primitive Data.Vector.Primitive.Mutable
    Data.Vector.Storable Data.Vector.Storable.Internal
    Data.Vector.Storable.Mutable Data.Vector.Unboxed
    Data.Vector.Unboxed.Base Data.Vector.Unboxed.Mutable Data.Version
    Data.Void Data.Void.Unsafe Data.Word Debug.Trace Foreign Foreign.C
    Foreign.C.Error Foreign.C.String Foreign.C.Types Foreign.Concurrent
    Foreign.ForeignPtr Foreign.ForeignPtr.Safe
    Foreign.ForeignPtr.Unsafe Foreign.Marshal Foreign.Marshal.Alloc
    Foreign.Marshal.Array Foreign.Marshal.Error Foreign.Marshal.Pool
    Foreign.Marshal.Safe Foreign.Marshal.Unsafe Foreign.Marshal.Utils
    Foreign.Ptr Foreign.Safe Foreign.StablePtr Foreign.Storable GHC.Arr
    GHC.Base GHC.Char GHC.Conc GHC.Conc.IO GHC.Conc.Signal
    GHC.Conc.Sync GHC.ConsoleHandler GHC.Constants GHC.Desugar GHC.Enum
    GHC.Environment GHC.Err GHC.Exception GHC.Exts GHC.Fingerprint
    GHC.Fingerprint.Type GHC.Float GHC.Float.ConversionUtils
    GHC.Float.RealFracMethods GHC.Foreign GHC.ForeignPtr GHC.GHCi
    GHC.Generics GHC.IO GHC.IO.Buffer GHC.IO.BufferedIO GHC.IO.Device
    GHC.IO.Encoding GHC.IO.Encoding.CodePage GHC.IO.Encoding.Failure
    GHC.IO.Encoding.Iconv GHC.IO.Encoding.Latin1 GHC.IO.Encoding.Types
    GHC.IO.Encoding.UTF16 GHC.IO.Encoding.UTF32 GHC.IO.Encoding.UTF8
    GHC.IO.Exception GHC.IO.FD GHC.IO.Handle GHC.IO.Handle.FD
    GHC.IO.Handle.Internals GHC.IO.Handle.Text GHC.IO.Handle.Types
    GHC.IO.IOMode GHC.IOArray GHC.IORef GHC.Int GHC.List GHC.MVar
    GHC.Num GHC.OverloadedLabels GHC.Pack GHC.Profiling GHC.Ptr
    GHC.Read GHC.Real GHC.Records GHC.ST GHC.STRef GHC.Show GHC.Stable
    GHC.Stack GHC.Stats GHC.Storable GHC.TopHandler GHC.TypeLits
    GHC.TypeNats GHC.Unicode GHC.Weak GHC.Word Numeric Numeric.Natural
    Prelude System.CPUTime System.Console.GetOpt System.Environment
    System.Exit System.IO System.IO.Error System.IO.Unsafe System.Info
    System.Mem System.Mem.StableName System.Mem.Weak
    System.Posix.Internals System.Posix.Types System.Timeout
    Text.ParserCombinators.ReadP Text.ParserCombinators.ReadPrec
    Text.Printf Text.Read Text.Read.Lex Text.Show Text.Show.Functions
    Unsafe.Coerce

import-dirs:          /usr/lib/ghc-9.4.8/site-local/rerebase-1.20
library-dirs:         /usr/lib/ghc-9.4.8/site-local/rerebase-1.20
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/rerebase-1.20
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-rerebase
hs-libraries:         HSrerebase-1.20-KILABYYoZGG2GSka2hVFDU
depends:              rebase-1.20-ECfyF91gkr2JLAYwx02cGp
haddock-interfaces:   /usr/share/doc/haskell-rerebase/html/rerebase.haddock
haddock-html:         /usr/share/doc/haskell-rerebase/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
